@@ -68,10 +68,10 @@ main(int argc, char *argv[])
 	opts.debug = NULL;
 
 	opts.truststore = NULL;
-	if (exists_dir("/etc/ssl/certs"))
-		opts.truststore = "/etc/ssl/certs";
-	else if (exists_file("/etc/ssl/cert.pem"))
-		opts.truststore = "/etc/ssl/cert.pem";
+	if (exists_dir(CONFIG_SSL_CAPATH))
+		capath = CONFIG_SSL_CAPATH;
+	if (exists_file(CONFIG_SSL_CAFILE))
+		cafile = CONFIG_SSL_CAFILE;
 
 	env.home = NULL;
 	env.pathmax = -1;
@@ -149,10 +149,13 @@ main(int argc, char *argv[])
 	tls12ctx = SSL_CTX_new(TLSv1_2_client_method());
 #endif
 #endif
-	if (exists_dir(opts.truststore))
+	if (exists_dir(opts.truststore)) {
 		capath = opts.truststore;
-	else if (exists_file(opts.truststore))
+		cafile = NULL;
+	} else if (exists_file(opts.truststore)) {
 		cafile = opts.truststore;
+		capath = NULL;
+	}
 #if OPENSSL_VERSION_NUMBER >= 0x1010000fL
 	if (sslctx)
 		SSL_CTX_load_verify_locations(sslctx, cafile, capath);
