@@ -47,6 +47,7 @@
 #define STATUS_READONLY			8
 #define STATUS_TRYCREATE		9
 #define STATUS_TIMEOUT			10
+#define STATUS_INTERRUPT                11
 
 #define STATUS_DRYRUN                   STATUS_OK
 
@@ -61,6 +62,9 @@
 #define LINE_MAX			2048
 #endif
 
+/* Wait retry timeout, in seconds, on network problems. */
+#define WAIT_RETRY_TIMEOUT              60
+
 
 /* Program's options. */
 typedef struct options {
@@ -210,12 +214,14 @@ int response_idle(session *ssn, int tag, char **event);
 /*	signal.c	*/
 void catch_signals(void);
 void release_signals(void);
+void ignore_user_signals(void);
+void catch_user_signals(void);
 
 /*	socket.c	*/
 int open_connection(session *ssn);
 int close_connection(session *ssn);
 ssize_t socket_read(session *ssn, char *buf, size_t len, long timeout,
-    int timeoutfail);
+    int timeoutfail, int *interrupt);
 ssize_t socket_write(session *ssn, const char *buf, size_t len);
 int open_secure_connection(session *ssn);
 int close_secure_connection(session *ssn);
